
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef GPS_MSG_LIB_H
#define GPS_MSG_LIB_H

#include "portLib.h"
#include "csLib.h"
#include "posterLib.h"
 
#include "GPSType.h"

#define TIME_WAIT_REPLY           /*2000*/ 0
 



/*----------- Tailles des messages et boites aux lettres  ----------*/

/* Taille du buffer utilise dans la bal pour un mesage de taille size
 * (cf servMbox pour UNIX et h2rgnLib pour VXWORKS )
 */


#define BUF_SIZE(size) \
   (size + 4 - (size & 3) + sizeof(LETTER_HDR) + 8)

/**
 ** Boite aux lettres reception requetes 
 **/
#define  GPS_MBOX_NAME                  genomInstanceName("GPS")

#define  GPS_MAX_RQST_SIZE              132

#define  GPS_MBOX_RQST_SIZE       \
 (BUF_SIZE(GPS_MAX_RQST_SIZE) * SERV_NMAX_RQST_ID)

/** 
 ** Taille max repliques (serveur)
 **/
#define  GPS_MAX_INTERMED_REPLY_SIZE   (sizeof(int))

#define  GPS_MAX_REPLY_SIZE             80

/** 
 ** Taille bal clients pour reception repliques 
 **/
#define  GPS_CLIENT_MBOX_REPLY_SIZE   \
((BUF_SIZE(GPS_MAX_REPLY_SIZE) \
   + BUF_SIZE(GPS_MAX_INTERMED_REPLY_SIZE)) \
 * CLIENT_NMAX_RQST_ID)

/*-------------------------- Liste des requetes  -------------------------*/

#define GPS_CONNECT_RQST 0
#define GPS_DISCONNECT_RQST 1
#define GPS_RECONNECT_RQST 2
#define GPS_SENDCOMMAND_RQST 3
#define GPS_LOG_RQST 4
#define GPS_STOPLOG_RQST 5
#define GPS_GETUTMPOS_RQST 6
#define GPS_GETPOSPOS_RQST 7
#define GPS_GETVEL_RQST 8
#define GPS_GETCONFIGURATION_RQST 9
#define GPS_SETPOM_RQST 10
#define GPS_SETPOSREF_RQST 11
#define GPS_GETPOSREF_RQST 12
#define GPS_SETHEADINGPOSTER_RQST 13
#define GPS_SETATTITUDEPOSTER_RQST 14
#define GPS_GETPOSQUALITY_RQST 15
#define GPS_STARTLOG_RQST 16
#define GPS_SETEXPORTGOODPOSTOPOM_RQST 17
#define GPS_ABORT_RQST 18


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif

STATUS GPSClientInit (CLIENT_ID *pClientId);

STATUS GPSClientEnd (CLIENT_ID clientId);

int GPSAbortRqstSend (CLIENT_ID clientId, 
			   int *pRqstId,
			   int *activity,
			   int replyTimeOut);

int GPSAbortReplyRcv (CLIENT_ID clientId, 
			   int rqstId, 
			   int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			   int *bilan);

int GPSAbortRqstAndRcv (CLIENT_ID clientId, 
			     int *activity,
			     int *bilan);




extern STATUS GPSConnectRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GPS_INIT *(in_gpsInit),
					 int replyTimeOut);

extern int GPSConnectReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int GPSConnectRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GPS_INIT *(in_gpsInit), 
					
					int *activity, int *bilan);

extern int GPSConnectRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GPS_INIT *(in_gpsInit), 
					
					int *activity,
					int *bilan);




extern STATUS GPSDisconnectRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int GPSDisconnectReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int GPSDisconnectRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int GPSDisconnectRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS GPSReconnectRqstSend (CLIENT_ID clientId, int *pRqstId,
					 
					 int replyTimeOut);

extern int GPSReconnectReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int GPSReconnectRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					 
					
					int *activity, int *bilan);

extern int GPSReconnectRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					 
					
					int *activity,
					int *bilan);




extern STATUS GPSSendCommandRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GEN_STRING128 *(in_order),
					 int replyTimeOut);

extern int GPSSendCommandReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int GPSSendCommandRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GEN_STRING128 *(in_order), 
					
					int *activity, int *bilan);

extern int GPSSendCommandRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GEN_STRING128 *(in_order), 
					
					int *activity,
					int *bilan);




extern STATUS GPSLogRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GEN_STRING128 *(in_fileName),
					 int replyTimeOut);

extern int GPSLogReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int GPSLogRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GEN_STRING128 *(in_fileName), 
					
					int *activity, int *bilan);

extern int GPSLogRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GEN_STRING128 *(in_fileName), 
					
					int *activity,
					int *bilan);




extern STATUS GPSStopLogRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int GPSStopLogReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int GPSStopLogRqstAndRcv (CLIENT_ID clientId, 
				  
				 
				 int *bilan);




extern STATUS GPSGetUTMPosRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int GPSGetUTMPosReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       OEM4BESTUTMb_LOG *(out_UTM),
			       int *bilan);

int GPSGetUTMPosRqstAndRcv (CLIENT_ID clientId, 
				  
				 OEM4BESTUTMb_LOG *(out_UTM),
				 int *bilan);




extern STATUS GPSGetPOSPosRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int GPSGetPOSPosReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       OEM4BESTPOSb_LOG *(out_POS),
			       int *bilan);

int GPSGetPOSPosRqstAndRcv (CLIENT_ID clientId, 
				  
				 OEM4BESTPOSb_LOG *(out_POS),
				 int *bilan);




extern STATUS GPSGetVelRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int GPSGetVelReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       OEM4BESTVELb_LOG *(out_vel),
			       int *bilan);

int GPSGetVelRqstAndRcv (CLIENT_ID clientId, 
				  
				 OEM4BESTVELb_LOG *(out_vel),
				 int *bilan);




extern STATUS GPSGetConfigurationRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int GPSGetConfigurationReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       GPS_INIT *(out_gpsInit),
			       int *bilan);

int GPSGetConfigurationRqstAndRcv (CLIENT_ID clientId, 
				  
				 GPS_INIT *(out_gpsInit),
				 int *bilan);




extern STATUS GPSSetPomRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GPS_POM_TAGGING *(in_pomTagging),
					 int replyTimeOut);

extern int GPSSetPomReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int GPSSetPomRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GPS_POM_TAGGING *(in_pomTagging), 
					
					int *activity, int *bilan);

extern int GPSSetPomRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GPS_POM_TAGGING *(in_pomTagging), 
					
					int *activity,
					int *bilan);




extern STATUS GPSSetPosRefRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 GPS_REF_POS *(in_posRef),
					 int replyTimeOut);

int GPSSetPosRefReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int GPSSetPosRefRqstAndRcv (CLIENT_ID clientId, 
				 GPS_REF_POS *(in_posRef), 
				 
				 int *bilan);




extern STATUS GPSGetPosRefRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int GPSGetPosRefReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       GPS_REF_POS *(out_posRef),
			       int *bilan);

int GPSGetPosRefRqstAndRcv (CLIENT_ID clientId, 
				  
				 GPS_REF_POS *(out_posRef),
				 int *bilan);




extern STATUS GPSSetHeadingPosterRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GPS_STRING *(in_headingPosterName),
					 int replyTimeOut);

extern int GPSSetHeadingPosterReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int GPSSetHeadingPosterRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GPS_STRING *(in_headingPosterName), 
					
					int *activity, int *bilan);

extern int GPSSetHeadingPosterRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GPS_STRING *(in_headingPosterName), 
					
					int *activity,
					int *bilan);




extern STATUS GPSSetAttitudePosterRqstSend (CLIENT_ID clientId, int *pRqstId,
					 GPS_STRING *(in_attitudePosterName),
					 int replyTimeOut);

extern int GPSSetAttitudePosterReplyRcv (CLIENT_ID clientId, int rqstId, 
				      int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY 
						     BLOCK_ON_INTERMED_REPLY */
				      
				      int *activity, int *bilan);


extern int GPSSetAttitudePosterRqstAndAck (CLIENT_ID clientId, int *pRqstId,
					int replyTimeOut,
					GPS_STRING *(in_attitudePosterName), 
					
					int *activity, int *bilan);

extern int GPSSetAttitudePosterRqstAndRcv (CLIENT_ID clientId, 
					int replyTimeOut,
					GPS_STRING *(in_attitudePosterName), 
					
					int *activity,
					int *bilan);




extern STATUS GPSGetPosQualityRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 
					 int replyTimeOut);

int GPSGetPosQualityReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       GPS_POS_QUALITY *(out_posQuality),
			       int *bilan);

int GPSGetPosQualityRqstAndRcv (CLIENT_ID clientId, 
				  
				 GPS_POS_QUALITY *(out_posQuality),
				 int *bilan);




extern STATUS GPSStartLogRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 GPS_LOG *(in_log),
					 int replyTimeOut);

int GPSStartLogReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int GPSStartLogRqstAndRcv (CLIENT_ID clientId, 
				 GPS_LOG *(in_log), 
				 
				 int *bilan);




extern STATUS GPSSetExportGoodPosToPomRqstSend (CLIENT_ID clientId, 
					 int *pRqstId,
					 GPS_FLAG *(in_stopExportingToPom),
					 int replyTimeOut);

int GPSSetExportGoodPosToPomReplyRcv (CLIENT_ID clientId, 
			       int rqstId, 
			       int block,  /* NO_BLOCK BLOCK_ON_FINAL_REPLY */
			       
			       int *bilan);

int GPSSetExportGoodPosToPomRqstAndRcv (CLIENT_ID clientId, 
				 GPS_FLAG *(in_stopExportingToPom), 
				 
				 int *bilan);


#ifdef __cplusplus
}
#endif
#endif /* GPS_MSG_LIB_H */

