
/* 
 * Copyright (c) 1993-2003,2012 LAAS/CNRS
 * All rights reserved.
 *
 * Redistribution and use  in source  and binary  forms,  with or without
 * modification, are permitted provided that the following conditions are
 * met:
 *
 *   1. Redistributions of  source  code must retain the  above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice,  this list of  conditions and the following disclaimer in
 *      the  documentation  and/or  other   materials provided  with  the
 *      distribution.
 *
 * THIS  SOFTWARE IS PROVIDED BY  THE  COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND  ANY  EXPRESS OR IMPLIED  WARRANTIES,  INCLUDING,  BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES  OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR  PURPOSE ARE DISCLAIMED. IN  NO EVENT SHALL THE COPYRIGHT
 * HOLDERS OR      CONTRIBUTORS  BE LIABLE FOR   ANY    DIRECT, INDIRECT,
 * INCIDENTAL,  SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF  SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN  CONTRACT, STRICT LIABILITY, OR
 * TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE   OF THIS SOFTWARE, EVEN   IF ADVISED OF   THE POSSIBILITY OF SUCH
 * DAMAGE.
 */

/*------------------  Fichier gnr automatiquement ------------------*/
/*------------------  Ne pas diter manuellement !!! ------------------*/

#ifndef GPS_POSTER_LIB_H
#define GPS_POSTER_LIB_H

#include "posterLib.h"
#include "genom/genom.h"

/* Types definis ou utilises par le module */
#include "GPSType.h"
#include "GPSError.h"

/* 
 * Definition de la SDI_C 
*/
typedef struct {
  CNTRL_TASK_DESCRIPTION cntrlTask;
  EXEC_TASK_DESCRIPTION execTaskTab[GPS_NB_EXEC_TASK];
  ACTIVITY_DESCRIPTION activityTab[MAX_ACTIVITIES];
} GPS_CNTRL_STR;

/* For consistency with other posters */
typedef GPS_CNTRL_STR GPS_CNTRL_POSTER_STR;
 
/* 
 * Definition des structures de posters
 */
#include "GPSPosterLibStruct.h"



/* Posters */
#define GPS_CNTRL_POSTER_NAME genomInstanceSuffixName("GPS", "Cntrl")
#define GPS_INFO_POSTER_NAME genomInstanceSuffixName("GPS", "Info")
#define GPS_MEPOS_POSTER_NAME genomInstanceSuffixName("GPS", "MEPos")
#define GPS_GPSDEBUG_POSTER_NAME genomInstanceSuffixName("GPS", "GPSDebug")


/*---------------- PROTOTYPES DES FONCTIONS EXTERNES ------------------*/

#ifdef __cplusplus
extern "C" {
#endif
extern STATUS GPSPosterInit ( void );
extern POSTER_ID GPSCntrlPosterID ();
extern STATUS GPSCntrlPosterRead ( GPS_CNTRL_STR *GPSCntrlStrId );
extern STATUS GPSCntrlPosterInit ( void );
extern STATUS GPSCntrlInstancePosterRead(const char *name, GPS_CNTRL_STR *GPSCntrlStrId);
extern STATUS GPSInfoPosterInit ( void );
extern POSTER_ID GPSInfoPosterID ( void );
extern STATUS GPSInfoPosterRead ( GPS_INFO_POSTER_STR *x );
extern STATUS GPSInfoInstancePosterRead ( const char *, GPS_INFO_POSTER_STR * );
extern STATUS GPSInfoutmPosterRead ( OEM4BESTUTMb_LOG *utm );
extern STATUS GPSInfoutmInstancePosterRead( const char *, OEM4BESTUTMb_LOG * );
extern STATUS GPSInfovelPosterRead ( OEM4BESTVELb_LOG *vel );
extern STATUS GPSInfovelInstancePosterRead( const char *, OEM4BESTVELb_LOG * );
extern STATUS GPSInfoheadingPosterRead ( OEM6HEADINGb_LOG *heading );
extern STATUS GPSInfoheadingInstancePosterRead( const char *, OEM6HEADINGb_LOG * );
extern STATUS GPSInfodate_utmPosterRead ( double *date_utm );
extern STATUS GPSInfodate_utmInstancePosterRead( const char *, double * );
extern STATUS GPSInfodate_velPosterRead ( double *date_vel );
extern STATUS GPSInfodate_velInstancePosterRead( const char *, double * );
extern STATUS GPSInfodate_headingPosterRead ( double *date_heading );
extern STATUS GPSInfodate_headingInstancePosterRead( const char *, double * );
extern STATUS GPSMEPosPosterInit ( void );
extern POSTER_ID GPSMEPosPosterID ( void );
extern STATUS GPSMEPosPosterRead ( GPS_MEPOS_POSTER_STR *x );
extern STATUS GPSMEPosInstancePosterRead ( const char *, GPS_MEPOS_POSTER_STR * );
extern STATUS GPSMEPosPosPosterRead ( POM_ME_POS *Pos );
extern STATUS GPSMEPosPosInstancePosterRead( const char *, POM_ME_POS * );
extern STATUS GPSGPSDebugPosterInit ( void );
extern POSTER_ID GPSGPSDebugPosterID ( void );
extern STATUS GPSGPSDebugPosterRead ( GPS_GPSDEBUG_POSTER_STR *x );
extern STATUS GPSGPSDebugInstancePosterRead ( const char *, GPS_GPSDEBUG_POSTER_STR * );
extern STATUS GPSGPSDebugdebugPosterRead ( GPS_DEBUG *debug );
extern STATUS GPSGPSDebugdebugInstancePosterRead( const char *, GPS_DEBUG * );
#ifdef __cplusplus
}
#endif
#endif

